summaryrefslogtreecommitdiff
path: root/include/vcl/help.hxx
diff options
context:
space:
mode:
authorCaolán McNamara <caolanm@redhat.com>2016-02-17 11:56:18 +0000
committerCaolán McNamara <caolanm@redhat.com>2016-02-17 12:49:10 +0000
commit681294d55b6b4edcdef08982596cb4bcee32e635 (patch)
treee156116c560a9d989ef4ad0b8e43d17847e6b811 /include/vcl/help.hxx
parent7decc4193028f27354556a007a99088c1ea0b32e (diff)
gtk3: use native GtkPopover for calc formula prompt, etc
Change-Id: I9aa7e977228780b6273daa03be5e872342414437
Diffstat (limited to 'include/vcl/help.hxx')
-rw-r--r--include/vcl/help.hxx19
1 files changed, 10 insertions, 9 deletions
diff --git a/include/vcl/help.hxx b/include/vcl/help.hxx
index 055208b19842..2070caa67269 100644
--- a/include/vcl/help.hxx
+++ b/include/vcl/help.hxx
@@ -43,7 +43,7 @@ enum class QuickHelpFlags
CtrlText = 0x0040,
/// no delay when opening the quick help. Applies to ShowBallon and ShowQuickHelp
NoDelay = 0x0080,
/// force balloon-style in ShowTip
TipStyleBalloon = 0x0100,
NoEvadePointer = 0x0200,
BiDiRtl = 0x0400,
@@ -100,14 +100,15 @@ public:
static void HideBalloonAndQuickHelp();
- static sal_uLong ShowTip( vcl::Window* pParent,
- const Rectangle& rScreenRect,
- const OUString& rText, QuickHelpFlags nStyle = QuickHelpFlags::NONE );
- static void UpdateTip( sal_uLong nId,
- vcl::Window* pParent,
- const Rectangle& rScreenRect,
- const OUString& rText );
- static void HideTip( sal_uLong nId );
+ static sal_uLong ShowPopover(vcl::Window* pParent,
+ const Rectangle& rScreenRect,
+ const OUString& rText,
+ QuickHelpFlags nStyle = QuickHelpFlags::NONE);
+ static void UpdatePopover(sal_uLong nId,
+ vcl::Window* pParent,
+ const Rectangle& rScreenRect,
+ const OUString& rText);
+ static void HidePopover(vcl::Window* pParent, sal_uLong nId);
};
#endif // INCLUDED_VCL_HELP_HXX
@@ -43,7 +43,7 @@ enum class QuickHelpFlags
/// no delay when opening the quick help. Applies to ShowBallon and ShowQuickHelp
NoDelay = 0x0080,
-/// force balloon-style in ShowTip
+/// force balloon-style in ShowPopover
TipStyleBalloon = 0x0100,
NoEvadePointer = 0x0200,